<?php

define( 'API_ENDPOINT', 'https://manager.shellrent.com/api' );

function doCurl( $method, $request, $POSTparams = [] ) {
	$method = strtoupper( $method );
	
	if( !in_array( $method, [ 'GET', 'POST' ] ) ) {
		$method = 'GET';
	}
	
	$Curl = curl_init();
	curl_setopt( $Curl, CURLOPT_URL, sprintf( '%s%s', API_ENDPOINT, $request ) );
	curl_setopt( $Curl, CURLOPT_ENCODING, 'UTF-8');
	curl_setopt( $Curl, CURLOPT_RETURNTRANSFER, true );
	curl_setopt( $Curl, CURLOPT_SSL_VERIFYPEER, false );	// Solo TEST
	curl_setopt( $Curl, CURLOPT_SSL_VERIFYHOST, false );	// Solo TEST
	curl_setopt( $Curl, CURLOPT_VERBOSE, false );
	curl_setopt( $Curl, CURLOPT_POST, ( $method == 'POST' ) );
	
	/* Parametri POST */
	if( !empty( $POSTparams ) ) {
		$fields = http_build_query( $POSTparams );
		curl_setopt( $Curl, CURLOPT_POSTFIELDS, $fields );
		curl_setopt( $Curl, CURLOPT_POST, true );
	}
	
	$Response = curl_exec( $Curl );
	
	if( curl_errno( $Curl ) != 0 ) {
		echo 'Errore nella richiesta HTTP';
		return false;
	}
	
	$HttpResponseCode = curl_getinfo( $Curl, CURLINFO_HTTP_CODE );
	
	if( $HttpResponseCode != 200 ) {
		echo sprintf( 'Errore HTTP: %s', $HttpResponseCode );
		return false;
	}
	
	curl_close( $Curl );
	
	return $Response;
}


/* Chiavi */
$apiAccesso = 'chiaveaccess';
$apiSegreto = 'chiavesecret';


/* 1. Login */
$response = doCurl( 'POST', '/login/request', [
	'REQUEST_KEY' => $apiAccesso,
]);

$parsed = json_decode( $response );

/*
Esempio di contenuto di $parsed:

stdClass Object
(
    [error] => 0
    [title] =>
    [message] =>
    [data] => stdClass Object
        (
            [CHALLENGE] => abc123......
        )
)
*/


/* 2. Risposta alla "Challenge" */
$response = doCurl( 'POST', '/login/verify', [
	'REQUEST_KEY' => $apiAccesso,
	'CHALLENGE' => hash( 'sha256', sprintf( '%s%s', $parsed->data->CHALLENGE, $apiSegreto ) ),
]);

$parsed = json_decode( $response );

/*
Esempio di contenuto di $parsed:

stdClass Object
(
    [error] => 0
    [title] =>
    [message] =>
    [data] => stdClass Object
        (
            [ACCESS_TOKEN] => 13134da1aa082c1b52630ac16073633e0524eabd6dd47bb649397bed86e23fec9bcbcd77cadf76854e95227241439953
        )
)
*/


/* 3. Richiesta */
$URL = '/index/hello/123_prova?ACCESS_TOKEN=' . $parsed->data->ACCESS_TOKEN;
$response = doCurl( 'GET', $URL );

$parsed = json_decode( $response );

/*
Esempio di contenuto di $parsed:

stdClass Object
(
    [error] => 0
    [title] =>
    [message] => Hello world
    [data] => stdClass Object
        (
            [data1] => Test
            [param] => 123_prova
        )
)
*/

